wheat_var_soil: Network of experiment to evaluate Wheat varieties on two contrasted soils.
Description
The data set consists of measurements of wheat yields from a network of field experiments
designed to evaluate and compare performances of different varieties or varietal mixtures.
This extract consists of 10 different experiments where 6 varieties or varietal mixtures where compared.
TODO : CHECK The experimental designs used are complete random block designs TODO : CHECK
The number of repetitions for a variety in each experiment varies from 3 to 4 (n_blocs).
Usage
wheat_var_soil
Arguments
Format
a RangedData instance, 1 row per measurement.
variete: variety, experimentation:experiment, rendement:Wheat Yield (ton/hectare), MSE:, ddl: ,n_blocs:number of repetition sol